/**
 * Copyright (C) 2008  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.console.navigation;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * ConsolePortletsConfig allow to configure the accessibility list of portlets
 * according to the user profile : group and membership. It allow also to
 * configure a default portlet list that is not under access control.
 * 
 * @author Elwalid Brahim <elwalid.brahim@bull.net>
 */

public class ConsolePortletsConfig {

  /* for each profile (membership and group) we have an accessible portlet list */
  private Map<String, List<ApplicationDefinition>> accessiblePortlets = new HashMap<String, List<ApplicationDefinition>>();

  /* the default accessible portlets (not under access control) */
  private List<ApplicationDefinition> defaultPortlets = new ArrayList<ApplicationDefinition>();

  /**
   * Get the list of accessible portlets according to the given group id and
   * membership id
   * 
   * @param groupId
   * @param membershipType
   * @return list of accessible portlets (applications)
   */
  public List<ApplicationDefinition> getAccessiblePortlets(String groupId, String membershipType) {
    return accessiblePortlets.get(membershipType + ":" + groupId);
  }

  /**
   * Add a list of accessible portlets to the given profile (group id and
   * membership id)
   * 
   * @param groupId
   * @param membershipType
   * @param accessiblePortlets
   */
  public void addAccessiblePortlets(String groupId, String membershipType, List<ApplicationDefinition> accessiblePortlets) {
    this.accessiblePortlets.put(membershipType + ":" + groupId, accessiblePortlets);
  }

  /**
   * Set the the accessible portlets list
   * 
   * @param accessiblePortlets
   */
  public void setAccessiblePortlets(Map<String, List<ApplicationDefinition>> accessiblePortlets) {
    this.accessiblePortlets = accessiblePortlets;
  }

  /**
   * Get the accessible portlets list
   * 
   * @return
   */
  public Map<String, List<ApplicationDefinition>> getAccessiblePortlets() {
    return accessiblePortlets;
  }

  /**
   * Set the the default portlets list
   * 
   * @param accessiblePortlets
   */
  public void setDefaultPortlets(List<ApplicationDefinition> defaultPortlets) {
    this.defaultPortlets = defaultPortlets;
  }

  /**
   * Get the default portlets list
   * 
   * @return
   */
  public List<ApplicationDefinition> getDefaultPortlets() {
    return defaultPortlets;
  }

}
