/**
 * Copyright (C) 2008  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.console.navigation;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.exoplatform.portal.application.PortalRequestContext;
import org.exoplatform.portal.webui.util.Util;
import org.exoplatform.web.application.ApplicationLifecycle;
import org.exoplatform.webui.application.WebuiRequestContext;

/**
 * Portal View Lifecycle is a listener on portal requests, It is used to
 * redirect the public access to the login page
 * 
 * @author Elwalid Brahim <elwalid.brahim@bull.net>
 */
public class PortalViewLifecycle implements ApplicationLifecycle<WebuiRequestContext> {

  /**
   * This method is called by the listener of the portal when a start request is
   * broadcasted. It allow to redirect the public access to the login page
   * 
   * @param Application component
   * @param The context of the webui request
   * @author Elwalid Brahim <elwalid.brahim@bull.net>
   * @throws Exception
   */
  public void onStartRequest(org.exoplatform.web.application.Application app, WebuiRequestContext rcontext) throws Exception {
    /**
     * Redirection of the public access to the login page (private access)
     */
    PortalRequestContext prContext = Util.getPortalRequestContext();
    if (prContext.getAccessPath() == PortalRequestContext.PUBLIC_ACCESS) {
      HttpServletRequest request = prContext.getRequest();
      String redirect = request.getContextPath();
      HttpServletResponse response = prContext.getResponse();
      response.getWriter().print("<script type=\"text/javascript\">location.href =\"" + redirect + "\";</script>");
    }
  }

  /**
   * This method is called by the listener of the portal when a destroy portal
   * request is broadcasted
   * 
   * @param Application component
   * @param The context of the webui request
   * @author Elwalid Brahim <elwalid.brahim@bull.net>
   * @throws Exception
   */
  public void onDestroy(org.exoplatform.web.application.Application app) throws Exception {
  }

  /**
   * This method is called by the listener of the portal when the end of a
   * portal request is broadcasted
   * 
   * @param Application component
   * @param The context of the webui request
   * @author Elwalid Brahim <elwalid.brahim@bull.net>
   * @throws Exception
   */
  public void onEndRequest(org.exoplatform.web.application.Application app, WebuiRequestContext context) throws Exception {
  }

  /**
   * This method is called by the listener of the portal when an init portal
   * request is broadcasted
   * 
   * @param Application component
   * @param The context of the webui request
   * @author Elwalid Brahim <elwalid.brahim@bull.net>
   * @throws Exception
   */
  public void onInit(org.exoplatform.web.application.Application app) throws Exception {
  }
}
